@@ -8,8 +8,9 @@ use open qw/:encoding(UTF-8) :std/;
 use Net::Whois::Norid;
 
 $Net::Whois::Raw::CHECK_FAIL = 1;
+$Net::Whois::Raw::OMIT_MSG = 1;
 
-use version; our $VERSION = qv('0.8.0');
+use version; our $VERSION = qv('0.8.2');
 
 use parent qw/Exporter/;
 our @EXPORT      = ();
@@ -19,9 +20,12 @@ our %EXPORT_TAGS = ( 'all' => [qw/domain2orgnr orgnr_ok orgnr2domains/] );
 sub domain2orgnr {
     my $domain = shift;
 
-    return if !$domain || $domain !~ /\.no$/;
+    return if not $domain;
+    return if $domain !~ /\.no$/;
+
     my $obj = Net::Whois::Norid->new($domain);
-    return exists $obj->{id_number} ? $obj->{id_number} : undef;
+
+    return $obj->{id_number};
 }
 
 sub orgnr2domains {
@@ -31,7 +35,6 @@ sub orgnr2domains {
 
     my @domains;
     my $obj = Net::Whois::Norid->new($orgnr);
-    return if not exists $obj->{norid_handle};
 
   HANDLE:
     for my $nh ( split /\n/, $obj->{norid_handle} ) {
@@ -83,7 +86,7 @@ No::OrgNr - Utility functions for Norwegian organizations' ID numbers
 
 =head1 VERSION
 
-This document describes No::OrgNr version 0.8.0
+This document describes No::OrgNr version 0.8.2
 
 
 =head1 SYNOPSIS
